@@ -74,24 +74,6 @@ macro_rules! assert_is_ata {
     };
 }
 
-/// Asserts that the given account matches the program id.
-#[macro_export]
-macro_rules! assert_program {
-    ($account: expr, $program: ident $(,)?) => {
-        let __account = anchor_lang::Key::key(&$account);
-        let __program_id: Pubkey = $crate::program_ids::$program::ID;
-        if __account != __program_id {
-            msg!(
-                "Incorrect program ID for program '{}': expected {}, found {}",
-                stringify!($program),
-                __program_id,
-                __account
-            );
-            return Err($crate::VipersError::ProgramIDMismatch.into());
-        }
-    };
-}
-
 /// Asserts that an account is owned by the given program.
 #[macro_export]
 macro_rules! assert_owner {
@@ -196,6 +178,23 @@ macro_rules! prog_require {
     };
 }
 
+/// Asserts that an invariant holds, otherwise logs the given message.
+///
+/// # Example
+///
+/// ```
+/// invariant!(1 == 2, "incorrect");
+/// ```
+#[macro_export]
+macro_rules! invariant {
+    ($invariant:expr, $err:expr $(,)?) => {
+        if !($invariant) {
+            msg!("Invariant failed: {:?}", $err);
+            return Err($crate::VipersError::IntegerOverflow.into());
+        }
+    };
+}
+
 #[cfg(test)]
 mod tests {
     use anchor_lang::prelude::*;
@@ -219,8 +218,6 @@ mod tests {
             "ATA"
         );
 
-        assert_program!(token::ID, token);
-
         let weird_math: Option<i32> = (1_i32).checked_add(2);
         let _result = unwrap_int!(weird_math);
 
