@@ -4,7 +4,6 @@
 #![allow(rustdoc::missing_doc_code_examples)]
 
 pub mod assert;
-pub mod program_ids;
 pub mod validate;
 
 use anchor_lang::prelude::*;
@@ -39,4 +38,6 @@ pub enum VipersError {
     OwnerMismatch,
     #[msg("The provided token account is not an associated token account.")]
     InvalidATA,
+    #[msg("Invariant failed.")]
+    InvariantFailed,
 }
